py21cmsense
===========

.. testsetup::

    from py21cmsense import *

.. autosummary::
    :toctree: _autosummary
    :template: module.rst

    py21cmsense.sensitivity
    py21cmsense.observation
    py21cmsense.observatory
    py21cmsense.theory
    py21cmsense.beam
    py21cmsense.antpos
    py21cmsense.conversions
